@@ -1,8 +1,9 @@
-from typing import Any, Dict, Union, cast
+from typing import Any, TypeVar, Union, cast
+from urllib.parse import urljoin
+
 import click
 import requests
-from typing import TypeVar
-from urllib.parse import urljoin
+from loguru import logger
 
 T = TypeVar("T")
 
@@ -11,10 +12,6 @@ class GableClient:
     def __init__(self, endpoint: str, api_key: str) -> None:
         self.endpoint = endpoint
         self.api_key = api_key
-
-        self.validate_api_key()
-        self.validate_endpoint()
-
         self.ui_endpoint = endpoint.replace("api-", "", 1)
 
     def validate_api_key(self):
@@ -31,16 +28,25 @@ class GableClient:
                 "environment variable."
             )
 
-    def get(self, path: str, **kwargs: Any) -> tuple[dict[str, Any], bool, int]:
+    def get(
+        self, path: str, **kwargs: Any
+    ) -> tuple[Union[list[Any], dict[str, Any]], bool, int]:
         return self._request(path, method="GET", **kwargs)
 
-    def post(self, path: str, **kwargs: Any) -> tuple[dict[str, Any], bool, int]:
+    def post(
+        self, path: str, **kwargs: Any
+    ) -> tuple[Union[list[Any], dict[str, Any]], bool, int]:
         return self._request(path, method="POST", **kwargs)
 
     def _request(
         self, path: str, method: str = "GET", **kwargs: Any
-    ) -> tuple[dict[str, Any], bool, int]:
+    ) -> tuple[Union[list[Any], dict[str, Any]], bool, int]:
+        self.validate_api_key()
+        self.validate_endpoint()
         url = urljoin(self.endpoint, path)
+
+        logger.debug(f"{method} {url}: {kwargs}")
+
         headers = {"X-API-KEY": self.api_key}
         if method.upper() == "GET":
             response = requests.get(url, headers=headers, **kwargs)
@@ -51,6 +57,10 @@ class GableClient:
         # Check for missing api key
         if response.status_code == 403:
             raise click.ClickException("Invalid API Key")
+        logger.debug(
+            f"{'OK' if response.ok else 'ERROR'} ({response.status_code}): {response.text}"
+        )
+
         return (
             cast(dict[str, Any], response.json()),
             response.status_code == 200,
