@@ -1,8 +1,11 @@
 import click
 from click.core import Context as ClickContext
+from gable.options import global_options
+from loguru import logger
 
 
 @click.command()
+@global_options()
 @click.pass_context
 def ping(ctx: ClickContext):
     """Pings the Gable API to check for connectivity"""
@@ -16,4 +19,4 @@ def ping(ctx: ClickContext):
         raise click.ClickException(
             f"Unable to ping Gable API at {ctx.obj.client.endpoint}"
         )
-    click.echo(f"Successfully pinged Gable API at {ctx.obj.client.endpoint}")
+    logger.info(f"Successfully pinged Gable API at {ctx.obj.client.endpoint}")
