@@ -1,10 +1,12 @@
-import click
 import json
-from typing import Any, Optional, Union
+from typing import Any, Optional, cast
+
+import click
 from gable.client import GableClient
+from gable.helpers.repo_interactions import get_git_repo_info, get_git_ssh_file_path
+from gable.options import DATABASE_SOURCE_TYPE_VALUES
 from gable.readers.dbapi import DbapiReader
-from gable.readers.file import get_file
-from gable.helpers.repo_interactions import get_git_ssh_file_path
+from gable.readers.file import read_file
 
 
 def standardize_source_type(source_type: str) -> str:
@@ -32,7 +34,7 @@ def get_db_connection(
             return create_postgres_connection(user, password, db, host, port)
         except ImportError:
             raise ImportError(
-                "The psycopg2 library not installed. Run `pip install gable-cli['postgres']` to install it."
+                "The psycopg2 library is not installed. Run `pip install 'gable[postgres]'` to install it."
             )
     elif source_type == "mysql":
         try:
@@ -41,15 +43,15 @@ def get_db_connection(
             return create_mysql_connection(user, password, db, host, port)
         except ImportError:
             raise ImportError(
-                "The MySQLdb library not installed. Run `pip install gable-cli['mysql']` to install it."
+                "The MySQLdb library is not installed. Run `pip install 'gable[mysql]'` to install it."
             )
 
 
 def get_db_schema_contents(
-    connection: Any, schema: str, table: Optional[str] = None
+    connection: Any, schema: str, tables: Optional[list[str]] = None
 ) -> list[dict[str, Any]]:
     reader = DbapiReader(connection=connection)
-    return reader.get_information_schema(schema=schema, table=table)  # type: ignore
+    return reader.get_information_schema(schema=schema, tables=tables)  # type: ignore
 
 
 def get_db_resource_name(
@@ -74,7 +76,7 @@ def get_schema_contents(
     dbhost: str,
     dbport: int,
     schema: str,
-    table: str,
+    tables: Optional[list[str]],
     files: list[str],
 ) -> list[str]:
     # Validate the source type arguments and get schema contents
@@ -83,11 +85,11 @@ def get_schema_contents(
         connection = get_db_connection(
             source_type, dbuser, dbpassword, db, dbhost, dbport
         )
-        return [json.dumps(get_db_schema_contents(connection, schema, table=table))]
+        return [json.dumps(get_db_schema_contents(connection, schema, tables=tables))]
     elif source_type in ["avro", "protobuf", "json_schema"]:
         schema_contents: list[str] = []
         for file in files:
-            schema_contents.append(get_file(file))
+            schema_contents.append(read_file(file))
     else:
         raise NotImplementedError(f"Unknown source type: {source_type}")
     return schema_contents
@@ -106,7 +108,7 @@ def get_source_names(
     elif source_type in ["avro", "protobuf", "json_schema"]:
         source_names = []
         for file in files:
-            source_names.append(get_git_ssh_file_path(ctx.obj.git_info, file))
+            source_names.append(get_git_ssh_file_path(get_git_repo_info(file), file))
         return source_names
     else:
         raise NotImplementedError(f"Unknown source type: {source_type}")
@@ -119,7 +121,7 @@ def send_schemas_to_gable(
     database_schema: str,
     schema_contents: list[str],
 ) -> tuple[dict[str, Any], bool, int]:
-    return client.post(
+    result, success, status_code = client.post(
         "v0/data-asset/ingest",
         json={
             "sourceType": source_type,
@@ -128,3 +130,29 @@ def send_schemas_to_gable(
             "schema": schema_contents,
         },
     )
+    return cast(dict[str, Any], result), success, status_code
+
+
+def is_empty_schema_contents(
+    source_type: str,
+    schema_contents: list[str],
+) -> bool:
+    if len(schema_contents) == 0 or (
+        # If we're registering a database table the schema_contents array will contain
+        # a stringified empty array, so we need to check for that
+        source_type in DATABASE_SOURCE_TYPE_VALUES
+        and len(schema_contents) == 1
+        and schema_contents[0] == "[]"  # type: ignore
+    ):
+        return True
+    return False
+
+
+def get_generated_data_asset_contract(
+    client: GableClient, data_asset_id: str
+) -> tuple[dict[str, Any], bool, int]:
+    """Use the infer contract endpoint to generate a contract for a data asset"""
+    response, success, status_code = client.get(
+        f"v0/data-asset/{data_asset_id}/infer-contract"
+    )
+    return cast(dict[str, Any], response), success, status_code
